SudGIPFSMGameDelegate class

Implemented types

Constructors

SudGIPFSMGameDelegate({void onGameLoadingProgress(int stage, int retCode, int progress)?, void onGameStarted()?, void onGameDestroyed()?, void onExpireCode(String dataJson)?, void onGameStateChange(String state, String dataJson)?, void onPlayerStateChange(String userId, String state, String dataJson)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
onExpireCode → void Function(String dataJson)?
final
onGameDestroyed → void Function()?
final
onGameLoadingProgress → void Function(int stage, int retCode, int progress)?
final
onGameStarted → void Function()?
final
onGameStateChange → void Function(String state, String dataJson)?
final
onPlayerStateChange → void Function(String userId, String state, String dataJson)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onExpireCodeCallback(String dataJson) → void
override
onGameDestroyedCallback() → void
override
onGameLoadingProgressCallback(int stage, int retCode, int progress) → void
override
onGameStartedCallback() → void
override
onGameStateChangeCallback(String state, String dataJson) → void
override
onPlayerStateChangeCallback(String userId, String state, String dataJson) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited