SudGIPFSMGame class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onExpireCodeCallback(
String dataJson) → void -
onGameDestroyedCallback(
) → void -
onGameLoadingProgressCallback(
int stage, int retCode, int progress) → void -
onGameStartedCallback(
) → void -
onGameStateChangeCallback(
String state, String dataJson) → void -
onPlayerStateChangeCallback(
String userId, String state, String dataJson) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited